@@ -45,11 +45,12 @@ def cache_data(func, timeout: int, by_args=False, enabled=True, custom_cache=Non
 
 
 @parametrized
-def log_exec_time(func, enabled=getattr(settings, 'DR_LOG_EXEC_TIME', False), log_args=False):
+def log_exec_time(func, func_name=None, enabled=getattr(settings, 'DR_LOG_EXEC_TIME', False), log_args=False):
     """
     Decorator to log calculate the execution time of the method.
 
     :param func: function to decorate
+    :param func_name: custom function name to log
     :param enabled: To enable or disable it. Can be enabled globally by setting DR_LOG_EXEC_TIME=True in django settings.
     :param log_args: Log arguments passed if *True*.
     """
@@ -57,7 +58,7 @@ def log_exec_time(func, enabled=getattr(settings, 'DR_LOG_EXEC_TIME', False), lo
     def wrapper(*args, **kwargs):
         args_flattened = (', args:' + ','.join(imap(str, args)) + ','.join([f'{k}:{v}' for (k, v) in kwargs.items()])
                           if log_args and enabled else '')
-        meta = f'fn:{func.__name__}{args_flattened}'
+        meta = func_name or f'fn:{func.__name__}{args_flattened}'
         logger = PrintLogger(f"log_exec_time ({meta})", enabled=enabled)
         start = datetime.now()
         resp = func(*args, **kwargs)
